==> jboss-eap-7.0.6-src.zip: jboss-eap-7.0-src/clustering/server/src/main/java/org/wildfly/clustering/server/dispatcher/CommandDispatcherClassTableContributor.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2013, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.wildfly.clustering.server.dispatcher;

import java.util.Arrays;
import java.util.Collection;

import org.wildfly.clustering.dispatcher.Command;
import org.wildfly.clustering.marshalling.jboss.ClassTableContributor;

/**
 * ClassTable contributor for the marshaller of a {@link CommandDispatcher}.
 * @author Paul Ferraro
 */
public class CommandDispatcherClassTableContributor implements ClassTableContributor {

    @Override
    public Collection<Class<?>> getKnownClasses() {
        return Arrays.<Class<?>>asList(Command.class, NoSuchService.class);
    }
}

==> jboss-eap-7.2.3-src.zip: jboss-eap-7.2-src/clustering/server/src/main/java/org/wildfly/clustering/server/dispatcher/CommandDispatcherClassTableContributor.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2013, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.wildfly.clustering.server.dispatcher;

import java.util.Arrays;
import java.util.List;
import java.util.concurrent.ExecutionException;

import org.kohsuke.MetaInfServices;
import org.wildfly.clustering.dispatcher.Command;
import org.wildfly.clustering.marshalling.jboss.ClassTableContributor;

/**
 * ClassTable contributor for the marshaller of a {@link org.wildfly.clustering.dispatcher.CommandDispatcher}.
 * @author Paul Ferraro
 */
@MetaInfServices(ClassTableContributor.class)
public class CommandDispatcherClassTableContributor implements ClassTableContributor {

    @Override
    public List<Class<?>> getKnownClasses() {
        return Arrays.<Class<?>>asList(Command.class, NoSuchService.class, ExecutionException.class);
    }
}
